@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright 2012 Canonical Ltd.
+# Copyright 2012 - 2015 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -15,6 +15,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-export QML_IMPORT_PATH=$PWD/modules
-export QML2_IMPORT_PATH=$PWD/modules
-export UBUNTU_UI_TOOLKIT_THEMES_PATH=$PWD/modules
+. `dirname $0`/build_paths.inc
+export QML_IMPORT_PATH=$BUILD_DIR/qml
+export QML2_IMPORT_PATH=$BUILD_DIR/qml
+export UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global QML_IMPORT_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global QML2_IMPORT_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/qml
